#
# spec file for package perl-Module-Runtime
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Module-Runtime
Version:        0.016
Release:        1.31
%define cpan_name Module-Runtime
Summary:        Runtime Module Handling
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Module-Runtime/
Source0:        https://cpan.metacpan.org/authors/id/Z/ZE/ZEFRAM/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Build)
%{perl_requires}

%description
The functions exported by this module deal with runtime handling of Perl
modules, which are normally handled at compile time. This module avoids
using any other modules, so that it can be used in low-level
infrastructure.

The parts of this module that work with module names apply the same syntax
that is used for barewords in Perl source. In principle this syntax can
vary between versions of Perl, and this module applies the syntax of the
Perl on which it is running. In practice the usable syntax hasn't changed
yet. There's some intent for Unicode module names to be supported in the
future, but this hasn't yet amounted to any consistent facility.

The functions of this module whose purpose is to load modules include
workarounds for three old Perl core bugs regarding 'require'. These
workarounds are applied on any Perl version where the bugs exist, except
for a case where one of the bugs cannot be adequately worked around in pure
Perl.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README

%changelog
* Thu Oct 19 2017 coolo@suse.com
- updated to 0.016
  see /usr/share/doc/packages/perl-Module-Runtime/Changes
  version 0.016; 2017-10-17
  * port t/taint.t to Perl 5.27.5, where re-requiring an already-loaded
    module doesn't trigger tainting
  * skip t/taint.t if the perl empirically doesn't perform taint checks
    but the script got run anyway (which happens with an unsupported
    configuration of the Perl core which some people are using in the
    absence of a supported no-taint configuration)
  * in t/taint.t, use $^X rather than $ENV{PATH} as the primordial
    tainted value to taint a string being tested
  * in documentation, use four-column indentation for all verbatim
    material
  * in META.{yml,json}, point to public bug tracker
  * in META.json, specify type of public repository
* Mon Jul 17 2017 coolo@suse.com
- updated to 0.015
  see /usr/share/doc/packages/perl-Module-Runtime/Changes
  version 0.015; 2017-07-16
  * update test suite to not rely on . in @INC, which is no longer
    necessarily there from Perl 5.25.7
  * in documentation, warn about the security problem with
    use_package_optimistically()
  * declare correct version for Test::More dependency
  * generate "traditional" style of compatibility Makefile.PL, to
    permit building in environments that don't support Build.PL or
    configure_requires
* Mon Feb 24 2014 coolo@suse.com
- updated to 0.014
  * bugfix: suppress any CORE::GLOBAL::require override, where possible,
    to avoid use_package_optimistically() being misled into treating
    missing modules as broken
  * bugfix: in use_module() and use_package_optimistically(), pass a
    supplied VERSION parameter through for the version check even if it
    is undef
  * tighten use_package_optimistically()'s recognition of can't-locate
    errors (the same way that base.pm has recently been tightened),
    so that, when a module fails to load because a module that it uses
    isn't available, the outer module will be perceived as broken rather
    than missing
  * update documentation notes about the state of Unicode handling for
    module names
  * in META.{yml,json}, point to public git repository
* Tue Jun 11 2013 coolo@suse.com
- rebuild for perl 5.18
* Fri Feb 17 2012 coolo@suse.com
- updated to 0.013
  * fix false failure of the test for lack of unintended dependencies
    that occurred on systems using a sitecustomize.pl
* Mon Feb 13 2012 coolo@suse.com
- updated to 0.012
  * work around Perl core bug [RT#68590] regarding leakage of %%^H
    into modules being loaded
  * work around Perl core bug that made a failed module loading appear
    successful when re-requiring the same module
  * duplicate is_string() from Params::Classify, rather than importing it,
    to avoid circular dependency problems (affecting both installation
    and runtime)
  * duplicate minimal exporting behaviour from Exporter, and avoid using
    the "feature", "warnings", "strict", and "parent" pragmata, to allow
    for possible future use of this module by any infrastructure module
  * document core bug workarounds
  * document module name syntax more prominently, and discuss the state
    of Unicode handling
  * tweak documentation of use_package_optimistically()
  * test behaviour with tainted module name
  * test lack of unwanted eval frame around require
  * give test modules more meaningful names
  * convert .cvsignore to .gitignore
* Wed Oct 26 2011 tabraham@novell.com
- initial package 0.011
  * created by cpanspec 1.78.06
